diff --git a/.devcontainer/devcontainer.json b/.devcontainer/devcontainer.json
index eefdb6bfe9e9..3b3c6b4f9216 100644
--- a/.devcontainer/devcontainer.json
+++ b/.devcontainer/devcontainer.json
@@ -5,8 +5,8 @@
"build": {
"dockerfile": "Dockerfile",
"args": {
- // Update 'VARIANT' to pick a .NET Core version: 2.1, 3.1, 5.0
- "VARIANT": "5.0",
+ // Update 'VARIANT' to pick a .NET Core version: 2.1, 3.1, 5.0, 6.0, 7.0
+ "VARIANT": "7.0",
// Options
"INSTALL_NODE": "true",
"NODE_VERSION": "lts/*"
@@ -31,7 +31,7 @@
"remoteEnv": {
"PATH": "${containerWorkspaceFolder}/.dotnet:${containerEnv:PATH}",
"DOTNET_MULTILEVEL_LOOKUP": "0",
- "TARGET": "net6.0"
+ "TARGET": "net7.0"
},
// Comment out connect as root instead. More info: https://aka.ms/vscode-remote/containers/non-root.
diff --git a/Directory.Build.props b/Directory.Build.props
index dc1f3554115a..204df64da7a4 100644
--- a/Directory.Build.props
+++ b/Directory.Build.props
@@ -104,7 +104,7 @@
$(MSBuildProjectDirectory)
true
- net461
+ net462
diff --git a/docs/DailyBuilds.md b/docs/DailyBuilds.md
index 276f36273275..3112a89339d2 100644
--- a/docs/DailyBuilds.md
+++ b/docs/DailyBuilds.md
@@ -12,7 +12,7 @@ If you want to download the latest daily build and use it in a project, then you
-
+
diff --git a/eng/Dependencies.props b/eng/Dependencies.props
index 5f5d2d1765c9..9587cc3b1214 100644
--- a/eng/Dependencies.props
+++ b/eng/Dependencies.props
@@ -116,6 +116,8 @@ and are generated based on the last package release.
+
+
diff --git a/eng/Version.Details.xml b/eng/Version.Details.xml
index 5647a4a1b245..5d51a88b5a27 100644
--- a/eng/Version.Details.xml
+++ b/eng/Version.Details.xml
@@ -9,292 +9,292 @@
-->
-
+
https://github.com/dotnet/efcore
- afab3dc9025790510de52805e007f3f73cccece5
+ 29230f22c1f938e52133cc11e7e82668788a4697
-
+
https://github.com/dotnet/efcore
- afab3dc9025790510de52805e007f3f73cccece5
+ 29230f22c1f938e52133cc11e7e82668788a4697
-
+
https://github.com/dotnet/efcore
- afab3dc9025790510de52805e007f3f73cccece5
+ 29230f22c1f938e52133cc11e7e82668788a4697
-
+
https://github.com/dotnet/efcore
- afab3dc9025790510de52805e007f3f73cccece5
+ 29230f22c1f938e52133cc11e7e82668788a4697
-
+
https://github.com/dotnet/efcore
- afab3dc9025790510de52805e007f3f73cccece5
+ 29230f22c1f938e52133cc11e7e82668788a4697
-
+
https://github.com/dotnet/efcore
- afab3dc9025790510de52805e007f3f73cccece5
+ 29230f22c1f938e52133cc11e7e82668788a4697
-
+
https://github.com/dotnet/efcore
- afab3dc9025790510de52805e007f3f73cccece5
+ 29230f22c1f938e52133cc11e7e82668788a4697
-
+
https://github.com/dotnet/efcore
- afab3dc9025790510de52805e007f3f73cccece5
+ 29230f22c1f938e52133cc11e7e82668788a4697
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
-
+
https://github.com/dotnet/runtime
- 7292301fc5e0071b2e6e0a7d221d82ba7199e73c
+ 6c9921d2ad188d81af53892930a87ee5ad97c979
https://github.com/dotnet/arcade
diff --git a/eng/Versions.props b/eng/Versions.props
index ac31df1e8666..20878b527800 100644
--- a/eng/Versions.props
+++ b/eng/Versions.props
@@ -43,7 +43,7 @@
src\Components\WebAssembly\Sdk\testassets\Directory.Build.props, and
src\Razor\test\testassets\Directory.Build.props when this changes.
-->
- net6.0
+ net7.0
@@ -65,78 +65,78 @@
-->
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
- 7.0.0-alpha.1.21457.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
+ 7.0.0-alpha.1.21470.1
- 7.0.0-alpha.1.21457.1
+ 7.0.0-alpha.1.21470.1
- 7.0.0-alpha.1.21458.26
- 7.0.0-alpha.1.21458.26
- 7.0.0-alpha.1.21458.26
- 7.0.0-alpha.1.21458.26
- 7.0.0-alpha.1.21458.26
- 7.0.0-alpha.1.21458.26
- 7.0.0-alpha.1.21458.26
- 7.0.0-alpha.1.21458.26
+ 7.0.0-alpha.1.21470.2
+ 7.0.0-alpha.1.21470.2
+ 7.0.0-alpha.1.21470.2
+ 7.0.0-alpha.1.21470.2
+ 7.0.0-alpha.1.21470.2
+ 7.0.0-alpha.1.21470.2
+ 7.0.0-alpha.1.21470.2
+ 7.0.0-alpha.1.21470.2
7.0.0-beta.21466.4
7.0.0-beta.21466.4
@@ -225,6 +225,9 @@
5.0.10-servicing-21410-22
$(MicrosoftAspNetCoreAzureAppServicesSiteExtension50Version)
$(MicrosoftAspNetCoreAzureAppServicesSiteExtension50Version)
+ 6.0.0-rc-1-21452-15
+ $(MicrosoftAspNetCoreAzureAppServicesSiteExtension60Version)
+ $(MicrosoftAspNetCoreAzureAppServicesSiteExtension60Version)
0.9.9
0.13.0
diff --git a/eng/Workarounds.targets b/eng/Workarounds.targets
index 90c2325eb95e..6b3f09647618 100644
--- a/eng/Workarounds.targets
+++ b/eng/Workarounds.targets
@@ -8,18 +8,6 @@
v$([MSBuild]::GetTargetFrameworkVersion('$(TargetFramework)', 2))
-
-
-
-
-
+ true
+ true
diff --git a/eng/tools/GenerateFiles/Directory.Build.targets.in b/eng/tools/GenerateFiles/Directory.Build.targets.in
index 53cd9040e933..da4844ca70b0 100644
--- a/eng/tools/GenerateFiles/Directory.Build.targets.in
+++ b/eng/tools/GenerateFiles/Directory.Build.targets.in
@@ -14,6 +14,11 @@
TargetFramework="${DefaultNetCoreTargetFramework}"
Condition="@(KnownAppHostPack->Count()) != '0' AND
!(@(KnownAppHostPack->AnyHaveMetadataValue('TargetFramework', '${DefaultNetCoreTargetFramework}')))" />
+
AnyHaveMetadataValue('TargetFramework', '${DefaultNetCoreTargetFramework}')))" />
+
+
+
+
+
4)
+ if (pathParts.Length < 3 || !pathParts[1].Equals("dotnet", StringComparison.Ordinal) || pathParts.Length > 5)
{
- Log.LogError($"Unexpected analyzer path format {path}. Expected 'analyzers/dotnet(/language)/analyzer.dll");
+ Log.LogError($"Unexpected analyzer path format {path}. Expected 'analyzers/dotnet(/roslyn)(/language)/analyzer.dll");
}
- // Check if we have enough parts for language directory and include it
- if (pathParts.Length > 3)
+ // Check if we have enough parts for language directory and include it.
+ // There could be a roslyn folder before the language folder. Check for it.
+ bool hasRoslynVersion = pathParts[2].StartsWith("roslyn", StringComparison.Ordinal);
+ int languageLengthCheck = hasRoslynVersion ? 4 : 3;
+ int potentialLanguageIndex = hasRoslynVersion ? 3 : 2;
+ if (pathParts.Length > languageLengthCheck)
{
- element.Add(new XAttribute("Language", pathParts[2]));
+ element.Add(new XAttribute("Language", pathParts[potentialLanguageIndex]));
}
}
diff --git a/eng/tools/RepoTasks/RepoTasks.csproj b/eng/tools/RepoTasks/RepoTasks.csproj
index 67e01850f836..5e495d347b30 100644
--- a/eng/tools/RepoTasks/RepoTasks.csproj
+++ b/eng/tools/RepoTasks/RepoTasks.csproj
@@ -1,6 +1,7 @@
- $(DefaultNetCoreTargetFramework)
+
+ net6.0
$(TargetFrameworks);net472
$(DefineConstants);BUILD_MSI_TASKS
false
@@ -19,7 +20,8 @@
-
+
+
diff --git a/eng/tools/RepoTasks/RepoTasks.tasks b/eng/tools/RepoTasks/RepoTasks.tasks
index ed3556653569..7483f6e41aae 100644
--- a/eng/tools/RepoTasks/RepoTasks.tasks
+++ b/eng/tools/RepoTasks/RepoTasks.tasks
@@ -1,5 +1,6 @@
+
<_RepoTaskAssemblyFolder Condition="'$(MSBuildRuntimeType)' == 'core'">net6.0
<_RepoTaskAssemblyFolder Condition="'$(MSBuildRuntimeType)' != 'core'">net472
<_RepoTaskAssembly>$(ArtifactsBinDir)RepoTasks\Release\$(_RepoTaskAssemblyFolder)\RepoTasks.dll
diff --git a/src/Components/Components/src/Microsoft.AspNetCore.Components.netcoreapp.nuspec b/src/Components/Components/src/Microsoft.AspNetCore.Components.netcoreapp.nuspec
index bc983db2fa0d..ebfc9e1e711f 100644
--- a/src/Components/Components/src/Microsoft.AspNetCore.Components.netcoreapp.nuspec
+++ b/src/Components/Components/src/Microsoft.AspNetCore.Components.netcoreapp.nuspec
@@ -3,7 +3,7 @@
$CommonMetadataElements$
-
+
diff --git a/src/Components/WebAssembly/DevServer/src/blazor-devserver.runtimeconfig.json.in b/src/Components/WebAssembly/DevServer/src/blazor-devserver.runtimeconfig.json.in
index e5bc81165938..b9734152e793 100644
--- a/src/Components/WebAssembly/DevServer/src/blazor-devserver.runtimeconfig.json.in
+++ b/src/Components/WebAssembly/DevServer/src/blazor-devserver.runtimeconfig.json.in
@@ -1,6 +1,6 @@
{
"runtimeOptions": {
- "tfm": "net6.0",
+ "tfm": "net7.0",
"framework": {
"name": "Microsoft.AspNetCore.App",
"version": "${SharedFxVersion}"
diff --git a/src/Components/benchmarkapps/Wasm.Performance/local.dockerfile b/src/Components/benchmarkapps/Wasm.Performance/local.dockerfile
index 2726fdcd79df..048e26cf799c 100644
--- a/src/Components/benchmarkapps/Wasm.Performance/local.dockerfile
+++ b/src/Components/benchmarkapps/Wasm.Performance/local.dockerfile
@@ -3,7 +3,7 @@ FROM selenium/standalone-chrome:latest as final
ENV StressRunDuration=0
WORKDIR /app
-COPY ./Driver/bin/Release/net6.0/linux-x64/publish ./
+COPY ./Driver/bin/Release/net7.0/linux-x64/publish ./
COPY ./exec.sh ./
ENTRYPOINT [ "bash", "./exec.sh" ]
diff --git a/src/DataProtection/Cryptography.KeyDerivation/src/PBKDF2/Pbkdf2Util.cs b/src/DataProtection/Cryptography.KeyDerivation/src/PBKDF2/Pbkdf2Util.cs
index 406aa27ce8d5..9de56635bc7a 100644
--- a/src/DataProtection/Cryptography.KeyDerivation/src/PBKDF2/Pbkdf2Util.cs
+++ b/src/DataProtection/Cryptography.KeyDerivation/src/PBKDF2/Pbkdf2Util.cs
@@ -14,7 +14,7 @@ internal static class Pbkdf2Util
private static IPbkdf2Provider GetPbkdf2Provider()
{
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
// In priority order, our three implementations are Win8, Win7, and "other".
if (OSVersionUtil.IsWindows8OrLater())
{
diff --git a/src/DataProtection/Cryptography.KeyDerivation/test/Pbkdf2Tests.cs b/src/DataProtection/Cryptography.KeyDerivation/test/Pbkdf2Tests.cs
index 23ab1a754d00..11b2ddf676fa 100644
--- a/src/DataProtection/Cryptography.KeyDerivation/test/Pbkdf2Tests.cs
+++ b/src/DataProtection/Cryptography.KeyDerivation/test/Pbkdf2Tests.cs
@@ -37,7 +37,7 @@ public void RunTest_Normal_NetCore(string password, KeyDerivationPrf prf, int it
}
// Act & assert
-#if NET461
+#if NETFRAMEWORK
TestProvider(password, salt, prf, iterationCount, numBytesRequested, expectedValueAsBase64);
#elif NETCOREAPP
TestProvider(password, salt, prf, iterationCount, numBytesRequested, expectedValueAsBase64);
@@ -53,7 +53,7 @@ public void RunTest_WithLongPassword_NetCore_FallbackToManaged()
byte[] salt = Encoding.UTF8.GetBytes("salt");
const string expectedDerivedKeyBase64 = "Sc+V/c3fiZq5Z5qH3iavAiojTsW97FAp2eBNmCQAwCNzA8hfhFFYyQLIMK65qPnBFHOHXQPwAxNQNhaEAH9hzfiaNBSRJpF9V4rpl02d5ZpI6cZbsQFF7TJW7XJzQVpYoPDgJlg0xVmYLhn1E9qMtUVUuXsBjOOdd7K1M+ZI00c=";
-#if NET461
+#if NETFRAMEWORK
RunTest_WithLongPassword_Impl(salt, expectedDerivedKeyBase64);
#elif NETCOREAPP
RunTest_WithLongPassword_Impl(salt, expectedDerivedKeyBase64);
@@ -68,7 +68,7 @@ public void RunTest_WithLongPassword_NetCore()
// salt longer than 8 bytes
var salt = Encoding.UTF8.GetBytes("abcdefghijkl");
-#if NET461
+#if NETFRAMEWORK
RunTest_WithLongPassword_Impl(salt, "NGJtFzYUaaSxu+3ZsMeZO5d/qPJDUYW4caLkFlaY0cLSYdh1PN4+nHUVp4pUUubJWu3UeXNMnHKNDfnn8GMfnDVrAGTv1lldszsvUJ0JQ6p4+daQEYBc//Tj/ejuB3luwW0IinyE7U/ViOQKbfi5pCZFMQ0FFx9I+eXRlyT+I74=");
#elif NETCOREAPP
RunTest_WithLongPassword_Impl(salt, "NGJtFzYUaaSxu+3ZsMeZO5d/qPJDUYW4caLkFlaY0cLSYdh1PN4+nHUVp4pUUubJWu3UeXNMnHKNDfnn8GMfnDVrAGTv1lldszsvUJ0JQ6p4+daQEYBc//Tj/ejuB3luwW0IinyE7U/ViOQKbfi5pCZFMQ0FFx9I+eXRlyT+I74=");
diff --git a/src/DataProtection/DataProtection/src/Managed/ManagedGenRandomImpl.cs b/src/DataProtection/DataProtection/src/Managed/ManagedGenRandomImpl.cs
index 5c7044b61cc1..de9e8ba70955 100644
--- a/src/DataProtection/DataProtection/src/Managed/ManagedGenRandomImpl.cs
+++ b/src/DataProtection/DataProtection/src/Managed/ManagedGenRandomImpl.cs
@@ -8,7 +8,7 @@ namespace Microsoft.AspNetCore.DataProtection.Managed
{
internal sealed unsafe class ManagedGenRandomImpl : IManagedGenRandom
{
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
private static readonly RandomNumberGenerator _rng = RandomNumberGenerator.Create();
#endif
public static readonly ManagedGenRandomImpl Instance = new ManagedGenRandomImpl();
@@ -20,7 +20,7 @@ private ManagedGenRandomImpl()
public byte[] GenRandom(int numBytes)
{
var bytes = new byte[numBytes];
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
_rng.GetBytes(bytes);
#else
RandomNumberGenerator.Fill(bytes);
diff --git a/src/DefaultBuilder/test/Microsoft.AspNetCore.FunctionalTests/WebHostFunctionalTests.cs b/src/DefaultBuilder/test/Microsoft.AspNetCore.FunctionalTests/WebHostFunctionalTests.cs
index c43de2410e20..ba7b2bcce92c 100644
--- a/src/DefaultBuilder/test/Microsoft.AspNetCore.FunctionalTests/WebHostFunctionalTests.cs
+++ b/src/DefaultBuilder/test/Microsoft.AspNetCore.FunctionalTests/WebHostFunctionalTests.cs
@@ -159,7 +159,7 @@ public async Task RunsInIISExpressInProcess()
var applicationName = "CreateDefaultBuilderApp";
var deploymentParameters = new DeploymentParameters(Path.Combine(GetTestSitesPath(), applicationName), ServerType.IISExpress, RuntimeFlavor.CoreClr, RuntimeArchitecture.x64)
{
- TargetFramework = "net6.0",
+ TargetFramework = "net7.0",
HostingModel = HostingModel.InProcess
};
@@ -214,7 +214,7 @@ private async Task ExecuteTestApp(string applicationName,
{
var deploymentParameters = new DeploymentParameters(Path.Combine(GetTestSitesPath(), applicationName), ServerType.Kestrel, RuntimeFlavor.CoreClr, RuntimeArchitecture.x64)
{
- TargetFramework = "net6.0",
+ TargetFramework = "net7.0",
};
if (setTestEnvVars)
diff --git a/src/FileProviders/Embedded/src/Microsoft.Extensions.FileProviders.Embedded.multitarget.nuspec b/src/FileProviders/Embedded/src/Microsoft.Extensions.FileProviders.Embedded.multitarget.nuspec
index 7df41c5eff33..3baf0ff505c6 100644
--- a/src/FileProviders/Embedded/src/Microsoft.Extensions.FileProviders.Embedded.multitarget.nuspec
+++ b/src/FileProviders/Embedded/src/Microsoft.Extensions.FileProviders.Embedded.multitarget.nuspec
@@ -3,7 +3,7 @@
$CommonMetadataElements$
-
+
diff --git a/src/FileProviders/Embedded/src/Microsoft.Extensions.FileProviders.Embedded.netcoreapp.nuspec b/src/FileProviders/Embedded/src/Microsoft.Extensions.FileProviders.Embedded.netcoreapp.nuspec
index 8e3f50ccf505..db17a2697ef1 100644
--- a/src/FileProviders/Embedded/src/Microsoft.Extensions.FileProviders.Embedded.netcoreapp.nuspec
+++ b/src/FileProviders/Embedded/src/Microsoft.Extensions.FileProviders.Embedded.netcoreapp.nuspec
@@ -3,7 +3,7 @@
$CommonMetadataElements$
-
+
diff --git a/src/Framework/App.Ref/src/Microsoft.AspNetCore.App.Ref.csproj b/src/Framework/App.Ref/src/Microsoft.AspNetCore.App.Ref.csproj
index dbb9913aacd3..ac853cbe3328 100644
--- a/src/Framework/App.Ref/src/Microsoft.AspNetCore.App.Ref.csproj
+++ b/src/Framework/App.Ref/src/Microsoft.AspNetCore.App.Ref.csproj
@@ -74,7 +74,7 @@ This package is an internal implementation of the .NET Core SDK and is not meant
+ but not required in net7.0 since the types required exist in System.Security.AccessControl. -->
diff --git a/src/Framework/App.Runtime/src/Microsoft.AspNetCore.App.Runtime.csproj b/src/Framework/App.Runtime/src/Microsoft.AspNetCore.App.Runtime.csproj
index 856f0e4fea64..d0fd38f161fd 100644
--- a/src/Framework/App.Runtime/src/Microsoft.AspNetCore.App.Runtime.csproj
+++ b/src/Framework/App.Runtime/src/Microsoft.AspNetCore.App.Runtime.csproj
@@ -123,7 +123,7 @@ This package is an internal implementation of the .NET Core SDK and is not meant
+ but not required in net7.0 since the types required exist in System.Security.AccessControl. -->
diff --git a/src/Framework/test/TestData.cs b/src/Framework/test/TestData.cs
index 1c7c5c1b4ec1..487968ececfd 100644
--- a/src/Framework/test/TestData.cs
+++ b/src/Framework/test/TestData.cs
@@ -234,55 +234,55 @@ static TestData()
{ "Microsoft.AspNetCore.StaticFiles", "7.0.0.0" },
{ "Microsoft.AspNetCore.WebSockets", "7.0.0.0" },
{ "Microsoft.AspNetCore.WebUtilities", "7.0.0.0" },
- { "Microsoft.Extensions.Caching.Abstractions", "6.0.0.0" },
- { "Microsoft.Extensions.Caching.Memory", "6.0.0.0" },
- { "Microsoft.Extensions.Configuration", "6.0.0.0" },
- { "Microsoft.Extensions.Configuration.Abstractions", "6.0.0.0" },
- { "Microsoft.Extensions.Configuration.Binder", "6.0.0.0" },
- { "Microsoft.Extensions.Configuration.CommandLine", "6.0.0.0" },
- { "Microsoft.Extensions.Configuration.EnvironmentVariables", "6.0.0.0" },
- { "Microsoft.Extensions.Configuration.FileExtensions", "6.0.0.0" },
- { "Microsoft.Extensions.Configuration.Ini", "6.0.0.0" },
- { "Microsoft.Extensions.Configuration.Json", "6.0.0.0" },
+ { "Microsoft.Extensions.Caching.Abstractions", "7.0.0.0" },
+ { "Microsoft.Extensions.Caching.Memory", "7.0.0.0" },
+ { "Microsoft.Extensions.Configuration", "7.0.0.0" },
+ { "Microsoft.Extensions.Configuration.Abstractions", "7.0.0.0" },
+ { "Microsoft.Extensions.Configuration.Binder", "7.0.0.0" },
+ { "Microsoft.Extensions.Configuration.CommandLine", "7.0.0.0" },
+ { "Microsoft.Extensions.Configuration.EnvironmentVariables", "7.0.0.0" },
+ { "Microsoft.Extensions.Configuration.FileExtensions", "7.0.0.0" },
+ { "Microsoft.Extensions.Configuration.Ini", "7.0.0.0" },
+ { "Microsoft.Extensions.Configuration.Json", "7.0.0.0" },
{ "Microsoft.Extensions.Configuration.KeyPerFile", "7.0.0.0" },
- { "Microsoft.Extensions.Configuration.UserSecrets", "6.0.0.0" },
- { "Microsoft.Extensions.Configuration.Xml", "6.0.0.0" },
- { "Microsoft.Extensions.DependencyInjection", "6.0.0.0" },
- { "Microsoft.Extensions.DependencyInjection.Abstractions", "6.0.0.0" },
+ { "Microsoft.Extensions.Configuration.UserSecrets", "7.0.0.0" },
+ { "Microsoft.Extensions.Configuration.Xml", "7.0.0.0" },
+ { "Microsoft.Extensions.DependencyInjection", "7.0.0.0" },
+ { "Microsoft.Extensions.DependencyInjection.Abstractions", "7.0.0.0" },
{ "Microsoft.Extensions.Diagnostics.HealthChecks", "7.0.0.0" },
{ "Microsoft.Extensions.Diagnostics.HealthChecks.Abstractions", "7.0.0.0" },
- { "Microsoft.Extensions.FileProviders.Abstractions", "6.0.0.0" },
- { "Microsoft.Extensions.FileProviders.Composite", "6.0.0.0" },
+ { "Microsoft.Extensions.FileProviders.Abstractions", "7.0.0.0" },
+ { "Microsoft.Extensions.FileProviders.Composite", "7.0.0.0" },
{ "Microsoft.Extensions.FileProviders.Embedded", "7.0.0.0" },
- { "Microsoft.Extensions.FileProviders.Physical", "6.0.0.0" },
- { "Microsoft.Extensions.FileSystemGlobbing", "6.0.0.0" },
+ { "Microsoft.Extensions.FileProviders.Physical", "7.0.0.0" },
+ { "Microsoft.Extensions.FileSystemGlobbing", "7.0.0.0" },
{ "Microsoft.Extensions.Features", "7.0.0.0" },
- { "Microsoft.Extensions.Hosting", "6.0.0.0" },
- { "Microsoft.Extensions.Hosting.Abstractions", "6.0.0.0" },
- { "Microsoft.Extensions.Http", "6.0.0.0" },
+ { "Microsoft.Extensions.Hosting", "7.0.0.0" },
+ { "Microsoft.Extensions.Hosting.Abstractions", "7.0.0.0" },
+ { "Microsoft.Extensions.Http", "7.0.0.0" },
{ "Microsoft.Extensions.Identity.Core", "7.0.0.0" },
{ "Microsoft.Extensions.Identity.Stores", "7.0.0.0" },
{ "Microsoft.Extensions.Localization", "7.0.0.0" },
{ "Microsoft.Extensions.Localization.Abstractions", "7.0.0.0" },
- { "Microsoft.Extensions.Logging", "6.0.0.0" },
- { "Microsoft.Extensions.Logging.Abstractions", "6.0.0.0" },
- { "Microsoft.Extensions.Logging.Configuration", "6.0.0.0" },
- { "Microsoft.Extensions.Logging.Console", "6.0.0.0" },
- { "Microsoft.Extensions.Logging.Debug", "6.0.0.0" },
- { "Microsoft.Extensions.Logging.EventLog", "6.0.0.0" },
- { "Microsoft.Extensions.Logging.EventSource", "6.0.0.0" },
- { "Microsoft.Extensions.Logging.TraceSource", "6.0.0.0" },
+ { "Microsoft.Extensions.Logging", "7.0.0.0" },
+ { "Microsoft.Extensions.Logging.Abstractions", "7.0.0.0" },
+ { "Microsoft.Extensions.Logging.Configuration", "7.0.0.0" },
+ { "Microsoft.Extensions.Logging.Console", "7.0.0.0" },
+ { "Microsoft.Extensions.Logging.Debug", "7.0.0.0" },
+ { "Microsoft.Extensions.Logging.EventLog", "7.0.0.0" },
+ { "Microsoft.Extensions.Logging.EventSource", "7.0.0.0" },
+ { "Microsoft.Extensions.Logging.TraceSource", "7.0.0.0" },
{ "Microsoft.Extensions.ObjectPool", "7.0.0.0" },
- { "Microsoft.Extensions.Options", "6.0.0.0" },
- { "Microsoft.Extensions.Options.ConfigurationExtensions", "6.0.0.0" },
- { "Microsoft.Extensions.Options.DataAnnotations", "6.0.0.0" },
- { "Microsoft.Extensions.Primitives", "6.0.0.0" },
+ { "Microsoft.Extensions.Options", "7.0.0.0" },
+ { "Microsoft.Extensions.Options.ConfigurationExtensions", "7.0.0.0" },
+ { "Microsoft.Extensions.Options.DataAnnotations", "7.0.0.0" },
+ { "Microsoft.Extensions.Primitives", "7.0.0.0" },
{ "Microsoft.Extensions.WebEncoders", "7.0.0.0" },
{ "Microsoft.JSInterop", "7.0.0.0" },
{ "Microsoft.Net.Http.Headers", "7.0.0.0" },
- { "System.Diagnostics.EventLog", "6.0.0.0" },
- { "System.IO.Pipelines", "6.0.0.0" },
- { "System.Security.Cryptography.Xml", "6.0.0.0" },
+ { "System.Diagnostics.EventLog", "7.0.0.0" },
+ { "System.IO.Pipelines", "7.0.0.0" },
+ { "System.Security.Cryptography.Xml", "7.0.0.0" },
};
if (!VerifyAncmBinary())
diff --git a/src/Hosting/Server.IntegrationTesting/src/Common/ApplicationType.cs b/src/Hosting/Server.IntegrationTesting/src/Common/ApplicationType.cs
index 72b1b01c5c25..cf7d3e77a829 100644
--- a/src/Hosting/Server.IntegrationTesting/src/Common/ApplicationType.cs
+++ b/src/Hosting/Server.IntegrationTesting/src/Common/ApplicationType.cs
@@ -11,7 +11,7 @@ public enum ApplicationType
Portable,
///
- /// All dlls are published with the app for x-copy deploy. Net461 requires this because ASP.NET Core is not in the GAC.
+ /// All dlls are published with the app for x-copy deploy. Net462 requires this because ASP.NET Core is not in the GAC.
///
Standalone
}
diff --git a/src/Hosting/Server.IntegrationTesting/src/Common/Tfm.cs b/src/Hosting/Server.IntegrationTesting/src/Common/Tfm.cs
index 6c8e0b81d388..040433afaaeb 100644
--- a/src/Hosting/Server.IntegrationTesting/src/Common/Tfm.cs
+++ b/src/Hosting/Server.IntegrationTesting/src/Common/Tfm.cs
@@ -7,7 +7,7 @@ namespace Microsoft.AspNetCore.Server.IntegrationTesting
{
public static class Tfm
{
- public const string Net461 = "net461";
+ public const string Net462 = "net462";
public const string NetCoreApp20 = "netcoreapp2.0";
public const string NetCoreApp21 = "netcoreapp2.1";
public const string NetCoreApp22 = "netcoreapp2.2";
@@ -15,7 +15,8 @@ public static class Tfm
public const string NetCoreApp31 = "netcoreapp3.1";
public const string Net50 = "net5.0";
public const string Net60 = "net6.0";
- public const string Default = Net60;
+ public const string Net70 = "net7.0";
+ public const string Default = Net70;
public static bool Matches(string tfm1, string tfm2)
{
diff --git a/src/Hosting/Server.IntegrationTesting/src/Deployers/ApplicationDeployer.cs b/src/Hosting/Server.IntegrationTesting/src/Deployers/ApplicationDeployer.cs
index ae8d171169d7..9571cf770a36 100644
--- a/src/Hosting/Server.IntegrationTesting/src/Deployers/ApplicationDeployer.cs
+++ b/src/Hosting/Server.IntegrationTesting/src/Deployers/ApplicationDeployer.cs
@@ -66,7 +66,7 @@ private void ValidateParameters()
private RuntimeFlavor GetRuntimeFlavor(string tfm)
{
- if (Tfm.Matches(Tfm.Net461, tfm))
+ if (Tfm.Matches(Tfm.Net462, tfm))
{
return RuntimeFlavor.Clr;
}
diff --git a/src/Hosting/Server.IntegrationTesting/src/Deployers/SelfHostDeployer.cs b/src/Hosting/Server.IntegrationTesting/src/Deployers/SelfHostDeployer.cs
index ccc2063b8fee..8bf99c859e92 100644
--- a/src/Hosting/Server.IntegrationTesting/src/Deployers/SelfHostDeployer.cs
+++ b/src/Hosting/Server.IntegrationTesting/src/Deployers/SelfHostDeployer.cs
@@ -98,7 +98,7 @@ public override async Task DeployAsync()
// Core+Standalone always publishes. This must be Clr+Standalone or Core+Portable.
// Run from the pre-built bin/{config}/{tfm} directory.
var targetFramework = DeploymentParameters.TargetFramework
- ?? (DeploymentParameters.RuntimeFlavor == RuntimeFlavor.Clr ? Tfm.Net461 : Tfm.NetCoreApp22);
+ ?? (DeploymentParameters.RuntimeFlavor == RuntimeFlavor.Clr ? Tfm.Net462 : Tfm.NetCoreApp22);
workingDirectory = Path.Combine(DeploymentParameters.ApplicationPath, "bin", DeploymentParameters.Configuration, targetFramework);
// CurrentDirectory will point to bin/{config}/{tfm}, but the config and static files aren't copied, point to the app base instead.
DeploymentParameters.EnvironmentVariables["ASPNETCORE_CONTENTROOT"] = DeploymentParameters.ApplicationPath;
diff --git a/src/Http/samples/MinimalSampleFSharp/MinimalSampleFSharp.fsproj b/src/Http/samples/MinimalSampleFSharp/MinimalSampleFSharp.fsproj
index 24e4bb3e6642..0bd1f42cf374 100644
--- a/src/Http/samples/MinimalSampleFSharp/MinimalSampleFSharp.fsproj
+++ b/src/Http/samples/MinimalSampleFSharp/MinimalSampleFSharp.fsproj
@@ -1,7 +1,7 @@
- net6.0
+ net7.0
diff --git a/src/Identity/Extensions.Core/src/PasswordHasher.cs b/src/Identity/Extensions.Core/src/PasswordHasher.cs
index 7645803aae7e..36d190f1a351 100644
--- a/src/Identity/Extensions.Core/src/PasswordHasher.cs
+++ b/src/Identity/Extensions.Core/src/PasswordHasher.cs
@@ -65,7 +65,7 @@ public PasswordHasher(IOptions optionsAccessor = null)
_rng = options.Rng;
}
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
// Compares two byte arrays for equality. The method is specifically written so that the loop is not optimized.
[MethodImpl(MethodImplOptions.NoInlining | MethodImplOptions.NoOptimization)]
private static bool ByteArraysEqual(byte[] a, byte[] b)
@@ -244,7 +244,7 @@ private static bool VerifyHashedPasswordV2(byte[] hashedPassword, string passwor
// Hash the incoming password and verify it
byte[] actualSubkey = KeyDerivation.Pbkdf2(password, salt, Pbkdf2Prf, Pbkdf2IterCount, Pbkdf2SubkeyLength);
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
return ByteArraysEqual(actualSubkey, expectedSubkey);
#elif NETCOREAPP
return CryptographicOperations.FixedTimeEquals(actualSubkey, expectedSubkey);
@@ -283,7 +283,7 @@ private static bool VerifyHashedPasswordV3(byte[] hashedPassword, string passwor
// Hash the incoming password and verify it
byte[] actualSubkey = KeyDerivation.Pbkdf2(password, salt, prf, iterCount, subkeyLength);
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
return ByteArraysEqual(actualSubkey, expectedSubkey);
#elif NETCOREAPP
return CryptographicOperations.FixedTimeEquals(actualSubkey, expectedSubkey);
diff --git a/src/Identity/Extensions.Core/src/Rfc6238AuthenticationService.cs b/src/Identity/Extensions.Core/src/Rfc6238AuthenticationService.cs
index 9ed628052bf7..fa5417549c2c 100644
--- a/src/Identity/Extensions.Core/src/Rfc6238AuthenticationService.cs
+++ b/src/Identity/Extensions.Core/src/Rfc6238AuthenticationService.cs
@@ -13,7 +13,7 @@ internal static class Rfc6238AuthenticationService
{
private static readonly TimeSpan _timestep = TimeSpan.FromMinutes(3);
private static readonly Encoding _encoding = new UTF8Encoding(false, true);
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
private static readonly DateTime _unixEpoch = new DateTime(1970, 1, 1, 0, 0, 0, DateTimeKind.Utc);
private static readonly RandomNumberGenerator _rng = RandomNumberGenerator.Create();
#endif
@@ -22,7 +22,7 @@ internal static class Rfc6238AuthenticationService
public static byte[] GenerateRandomKey()
{
byte[] bytes = new byte[20];
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
_rng.GetBytes(bytes);
#else
RandomNumberGenerator.Fill(bytes);
@@ -68,7 +68,7 @@ private static byte[] ApplyModifier(byte[] input, string modifier)
// More info: https://tools.ietf.org/html/rfc6238#section-4
private static ulong GetCurrentTimeStepNumber()
{
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
var delta = DateTime.UtcNow - _unixEpoch;
#else
var delta = DateTimeOffset.UtcNow - DateTimeOffset.UnixEpoch;
diff --git a/src/Identity/Extensions.Core/src/UserManager.cs b/src/Identity/Extensions.Core/src/UserManager.cs
index 775922edcaff..422512515b14 100644
--- a/src/Identity/Extensions.Core/src/UserManager.cs
+++ b/src/Identity/Extensions.Core/src/UserManager.cs
@@ -42,7 +42,7 @@ public class UserManager : IDisposable where TUser : class
new Dictionary>();
private bool _disposed;
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
private static readonly RandomNumberGenerator _rng = RandomNumberGenerator.Create();
#endif
private readonly IServiceProvider _services;
@@ -2429,7 +2429,7 @@ private IUserRoleStore GetUserRoleStore()
private static string NewSecurityStamp()
{
byte[] bytes = new byte[20];
-#if NETSTANDARD2_0 || NET461
+#if NETSTANDARD2_0 || NETFRAMEWORK
_rng.GetBytes(bytes);
#else
RandomNumberGenerator.Fill(bytes);
diff --git a/src/Middleware/Spa/SpaServices.Extensions/src/Proxying/SpaProxy.cs b/src/Middleware/Spa/SpaServices.Extensions/src/Proxying/SpaProxy.cs
index 3dd9aa3aae26..0f64afdb40e8 100644
--- a/src/Middleware/Spa/SpaServices.Extensions/src/Proxying/SpaProxy.cs
+++ b/src/Middleware/Spa/SpaServices.Extensions/src/Proxying/SpaProxy.cs
@@ -241,7 +241,7 @@ private static async Task AcceptProxyWebSocketRequest(HttpContext context,
}
catch (ArgumentException)
{
- // On net461, certain header names are reserved and can't be set.
+ // On net462, certain header names are reserved and can't be set.
// We filter out the known ones via the test above, but there could
// be others arbitrarily set by the client. It's not helpful to
// consider it an error, so just skip non-forwardable headers.
diff --git a/src/Middleware/WebSockets/samples/AutobahnTestAppAspNet4/packages.config b/src/Middleware/WebSockets/samples/AutobahnTestAppAspNet4/packages.config
index 5f629e51b2e2..b5a8c2c4142a 100644
--- a/src/Middleware/WebSockets/samples/AutobahnTestAppAspNet4/packages.config
+++ b/src/Middleware/WebSockets/samples/AutobahnTestAppAspNet4/packages.config
@@ -1,5 +1,5 @@
-
-
-
\ No newline at end of file
+
+
+
diff --git a/src/Middleware/WebSockets/test/ConformanceTests/Autobahn/AutobahnTester.cs b/src/Middleware/WebSockets/test/ConformanceTests/Autobahn/AutobahnTester.cs
index 94b58f678ff5..704496615a09 100644
--- a/src/Middleware/WebSockets/test/ConformanceTests/Autobahn/AutobahnTester.cs
+++ b/src/Middleware/WebSockets/test/ConformanceTests/Autobahn/AutobahnTester.cs
@@ -142,7 +142,7 @@ public async Task DeployTestAndAddToSpec(ServerType server, bool ssl, string env
{
Scheme = (ssl ? Uri.UriSchemeHttps : Uri.UriSchemeHttp),
ApplicationType = ApplicationType.Portable,
- TargetFramework = "Net6.0",
+ TargetFramework = "Net7.0",
EnvironmentName = environment,
SiteName = "HttpTestSite", // This is configured in the Http.config
ServerConfigTemplateContent = (server == ServerType.IISExpress) ? File.ReadAllText(configPath) : null,
diff --git a/src/Mvc/Mvc.TagHelpers/test/CacheTagHelperTest.cs b/src/Mvc/Mvc.TagHelpers/test/CacheTagHelperTest.cs
index 9c5a41426425..4970d991a457 100644
--- a/src/Mvc/Mvc.TagHelpers/test/CacheTagHelperTest.cs
+++ b/src/Mvc/Mvc.TagHelpers/test/CacheTagHelperTest.cs
@@ -485,6 +485,7 @@ public async Task ProcessAsync_UsesExpiresSliding_ToExpireCacheEntryWithSlidingE
}
[Fact]
+ [QuarantinedTest("https://github.com/dotnet/aspnetcore/issues/36765")]
public async Task ProcessAsync_FlowsEntryLinkThatAllowsAddingTriggersToAddedEntry()
{
// Arrange
diff --git a/src/Mvc/Mvc.Testing/src/buildTransitive/Microsoft.AspNetCore.Mvc.Testing.targets b/src/Mvc/Mvc.Testing/src/buildTransitive/Microsoft.AspNetCore.Mvc.Testing.targets
index 0d78409542f5..da544556a57a 100644
--- a/src/Mvc/Mvc.Testing/src/buildTransitive/Microsoft.AspNetCore.Mvc.Testing.targets
+++ b/src/Mvc/Mvc.Testing/src/buildTransitive/Microsoft.AspNetCore.Mvc.Testing.targets
@@ -1,5 +1,3 @@
-
-
-
+
diff --git a/src/Mvc/perf/benchmarkapps/BasicApi/Migrations/20180609000420_InitialCreate.cs b/src/Mvc/perf/benchmarkapps/BasicApi/Migrations/20180609000420_InitialCreate.cs
index 2dd749ebbcb6..c39ac98f1832 100644
--- a/src/Mvc/perf/benchmarkapps/BasicApi/Migrations/20180609000420_InitialCreate.cs
+++ b/src/Mvc/perf/benchmarkapps/BasicApi/Migrations/20180609000420_InitialCreate.cs
@@ -13,7 +13,7 @@ protected override void Up(MigrationBuilder migrationBuilder)
columns: table => new
{
Id = table.Column(nullable: false)
-#if !NET461
+#if !NETFRAMEWORK
.Annotation("MySql:ValueGenerationStrategy", MySqlValueGenerationStrategy.IdentityColumn)
#endif
.Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.SerialColumn)
@@ -31,7 +31,7 @@ protected override void Up(MigrationBuilder migrationBuilder)
columns: table => new
{
Id = table.Column(nullable: false)
-#if !NET461
+#if !NETFRAMEWORK
.Annotation("MySql:ValueGenerationStrategy", MySqlValueGenerationStrategy.IdentityColumn)
#endif
.Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.SerialColumn)
@@ -59,7 +59,7 @@ protected override void Up(MigrationBuilder migrationBuilder)
columns: table => new
{
Id = table.Column(nullable: false)
-#if !NET461
+#if !NETFRAMEWORK
.Annotation("MySql:ValueGenerationStrategy", MySqlValueGenerationStrategy.IdentityColumn)
#endif
.Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.SerialColumn)
@@ -84,7 +84,7 @@ protected override void Up(MigrationBuilder migrationBuilder)
columns: table => new
{
Id = table.Column(nullable: false)
-#if !NET461
+#if !NETFRAMEWORK
.Annotation("MySql:ValueGenerationStrategy", MySqlValueGenerationStrategy.IdentityColumn)
#endif
.Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.SerialColumn)
diff --git a/src/Mvc/perf/benchmarkapps/BasicApi/Startup.cs b/src/Mvc/perf/benchmarkapps/BasicApi/Startup.cs
index ac4fbe5e36cc..b1db2fa974fd 100644
--- a/src/Mvc/perf/benchmarkapps/BasicApi/Startup.cs
+++ b/src/Mvc/perf/benchmarkapps/BasicApi/Startup.cs
@@ -64,7 +64,7 @@ public void ConfigureServices(IServiceCollection services)
switch (databaseType.ToUpperInvariant())
{
-#if !NET461
+#if !NETFRAMEWORK
case "MYSQL":
services
.AddEntityFrameworkMySql()
diff --git a/src/Mvc/perf/benchmarkapps/BasicViews/Migrations/20180609000611_InitialCreate.cs b/src/Mvc/perf/benchmarkapps/BasicViews/Migrations/20180609000611_InitialCreate.cs
index 9eba0303393d..093cb04eeb79 100644
--- a/src/Mvc/perf/benchmarkapps/BasicViews/Migrations/20180609000611_InitialCreate.cs
+++ b/src/Mvc/perf/benchmarkapps/BasicViews/Migrations/20180609000611_InitialCreate.cs
@@ -14,7 +14,7 @@ protected override void Up(MigrationBuilder migrationBuilder)
columns: table => new
{
Id = table.Column(nullable: false)
-#if !NET461
+#if !NETFRAMEWORK
.Annotation("MySql:ValueGenerationStrategy", MySqlValueGenerationStrategy.IdentityColumn)
#endif
.Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.SerialColumn)
diff --git a/src/Mvc/perf/benchmarkapps/BasicViews/Startup.cs b/src/Mvc/perf/benchmarkapps/BasicViews/Startup.cs
index 6da2d7b19e39..cf4914be126c 100644
--- a/src/Mvc/perf/benchmarkapps/BasicViews/Startup.cs
+++ b/src/Mvc/perf/benchmarkapps/BasicViews/Startup.cs
@@ -45,7 +45,7 @@ public void ConfigureServices(IServiceCollection services)
switch (databaseType.ToUpperInvariant())
{
-#if !NET461
+#if !NETFRAMEWORK
case "MYSQL":
services
.AddEntityFrameworkMySql()
diff --git a/src/Mvc/test/Mvc.FunctionalTests/HtmlGenerationTest.cs b/src/Mvc/test/Mvc.FunctionalTests/HtmlGenerationTest.cs
index 63fd9a554438..4e892ed015f6 100644
--- a/src/Mvc/test/Mvc.FunctionalTests/HtmlGenerationTest.cs
+++ b/src/Mvc/test/Mvc.FunctionalTests/HtmlGenerationTest.cs
@@ -526,6 +526,7 @@ public async Task CacheTagHelper_VariesByUserId()
}
[Fact]
+ [QuarantinedTest("https://github.com/dotnet/aspnetcore/issues/36765")]
public async Task CacheTagHelper_BubblesExpirationOfNestedTagHelpers()
{
// Arrange & Act - 1
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/BlazorServerWeb-CSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/BlazorServerWeb-CSharp/.template.config/template.json
index 254598a9cfe2..378bf3ecfa67 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/BlazorServerWeb-CSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/BlazorServerWeb-CSharp/.template.config/template.json
@@ -439,12 +439,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/ComponentsWebAssembly-CSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/ComponentsWebAssembly-CSharp/.template.config/template.json
index cd44728a4894..bf14b44e1e97 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/ComponentsWebAssembly-CSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/ComponentsWebAssembly-CSharp/.template.config/template.json
@@ -286,12 +286,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"HostIdentifier": {
"type": "bind",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/EmptyWeb-CSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/EmptyWeb-CSharp/.template.config/template.json
index 3b7edb411a86..b4c0deb679df 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/EmptyWeb-CSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/EmptyWeb-CSharp/.template.config/template.json
@@ -130,12 +130,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/EmptyWeb-FSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/EmptyWeb-FSharp/.template.config/template.json
index 8149a3e89372..cd3e6f4511d1 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/EmptyWeb-FSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/EmptyWeb-FSharp/.template.config/template.json
@@ -126,12 +126,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/GrpcService-CSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/GrpcService-CSharp/.template.config/template.json
index 2fd14ec9251f..c47573b563b3 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/GrpcService-CSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/GrpcService-CSharp/.template.config/template.json
@@ -41,11 +41,11 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "defaultValue": "net6.0"
+ "defaultValue": "net7.0"
},
"ExcludeLaunchSettings": {
"type": "parameter",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/RazorClassLibrary-CSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/RazorClassLibrary-CSharp/.template.config/template.json
index 3ef9e65cff98..9c5869dbcabc 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/RazorClassLibrary-CSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/RazorClassLibrary-CSharp/.template.config/template.json
@@ -48,11 +48,11 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "defaultValue": "net6.0"
+ "defaultValue": "net7.0"
},
"HostIdentifier": {
"type": "bind",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/RazorPagesWeb-CSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/RazorPagesWeb-CSharp/.template.config/template.json
index d7226586d37d..e8bfff4684ae 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/RazorPagesWeb-CSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/RazorPagesWeb-CSharp/.template.config/template.json
@@ -361,12 +361,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/StarterWeb-CSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/StarterWeb-CSharp/.template.config/template.json
index b67fe4f719ef..930a83463da7 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/StarterWeb-CSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/StarterWeb-CSharp/.template.config/template.json
@@ -351,12 +351,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/StarterWeb-FSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/StarterWeb-FSharp/.template.config/template.json
index a6ceb4e1a9eb..b44038f7ef29 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/StarterWeb-FSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/StarterWeb-FSharp/.template.config/template.json
@@ -131,12 +131,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/WebApi-CSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/WebApi-CSharp/.template.config/template.json
index 1e871b3b8a22..edb6e3a7805c 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/WebApi-CSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/WebApi-CSharp/.template.config/template.json
@@ -299,12 +299,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/WebApi-FSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/WebApi-FSharp/.template.config/template.json
index 6ffb6d864bf5..aac3850a0cf9 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/WebApi-FSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/WebApi-FSharp/.template.config/template.json
@@ -126,12 +126,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/Worker-CSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/Worker-CSharp/.template.config/template.json
index 19358bf86a30..ef92f75ea68f 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/Worker-CSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/Worker-CSharp/.template.config/template.json
@@ -47,12 +47,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/Web.ProjectTemplates/content/Worker-FSharp/.template.config/template.json b/src/ProjectTemplates/Web.ProjectTemplates/content/Worker-FSharp/.template.config/template.json
index 3343d3660722..168add3cec8c 100644
--- a/src/ProjectTemplates/Web.ProjectTemplates/content/Worker-FSharp/.template.config/template.json
+++ b/src/ProjectTemplates/Web.ProjectTemplates/content/Worker-FSharp/.template.config/template.json
@@ -47,12 +47,12 @@
"datatype": "choice",
"choices": [
{
- "choice": "net6.0",
- "description": "Target net6.0"
+ "choice": "net7.0",
+ "description": "Target net7.0"
}
],
- "replaces": "net6.0",
- "defaultValue": "net6.0"
+ "replaces": "net7.0",
+ "defaultValue": "net7.0"
},
"copyrightYear": {
"type": "generated",
diff --git a/src/ProjectTemplates/scripts/Test-Template.ps1 b/src/ProjectTemplates/scripts/Test-Template.ps1
index 349174ad3d06..242558493d05 100644
--- a/src/ProjectTemplates/scripts/Test-Template.ps1
+++ b/src/ProjectTemplates/scripts/Test-Template.ps1
@@ -47,10 +47,10 @@ function Test-Template($templateName, $templateArgs, $templateNupkg, $isBlazorWa
foreach ($projPath in $proj) {
$projContent = Get-Content -Path $projPath -Raw
if ($isBlazorWasmHosted) {
- $importPath = "$PSScriptRoot/../test/bin/Debug/net6.0/TestTemplates"
+ $importPath = "$PSScriptRoot/../test/bin/Debug/net7.0/TestTemplates"
}
else {
- $importPath = "$PSScriptRoot/../test/bin/Debug/net6.0/TestTemplates"
+ $importPath = "$PSScriptRoot/../test/bin/Debug/net7.0/TestTemplates"
}
$projContent = $projContent -replace ('(?:)', ('
@@ -66,7 +66,7 @@ function Test-Template($templateName, $templateArgs, $templateNupkg, $isBlazorWa
}
dotnet.exe ef migrations add mvc
dotnet.exe publish --configuration Release
- Set-Location .\bin\Release\net6.0\publish
+ Set-Location .\bin\Release\net7.0\publish
if ($isBlazorWasm -eq $false) {
Invoke-Expression "./$templateName.exe"
}
diff --git a/src/Razor/Microsoft.AspNetCore.Razor.Language/test/Microsoft.AspNetCore.Razor.Language.Test.csproj b/src/Razor/Microsoft.AspNetCore.Razor.Language/test/Microsoft.AspNetCore.Razor.Language.Test.csproj
index 0c11cef119db..812568c3ba70 100644
--- a/src/Razor/Microsoft.AspNetCore.Razor.Language/test/Microsoft.AspNetCore.Razor.Language.Test.csproj
+++ b/src/Razor/Microsoft.AspNetCore.Razor.Language/test/Microsoft.AspNetCore.Razor.Language.Test.csproj
@@ -8,8 +8,6 @@
false
-
- false
false
diff --git a/src/Shared/BenchmarkRunner/DefaultCoreConfig.cs b/src/Shared/BenchmarkRunner/DefaultCoreConfig.cs
index 97ae3feb104c..9a4b53dfff7c 100644
--- a/src/Shared/BenchmarkRunner/DefaultCoreConfig.cs
+++ b/src/Shared/BenchmarkRunner/DefaultCoreConfig.cs
@@ -38,6 +38,8 @@ public DefaultCoreConfig()
.WithToolchain(CsProjCoreToolchain.From(new NetCoreAppSettings("net5.0", null, ".NET Core 5.0")))
#elif NET6_0
.WithToolchain(CsProjCoreToolchain.From(new NetCoreAppSettings("net6.0", null, ".NET Core 6.0")))
+#elif NET7_0
+ .WithToolchain(CsProjCoreToolchain.From(new NetCoreAppSettings("net7.0", null, ".NET Core 7.0")))
#else
#error Target frameworks need to be updated.
#endif
diff --git a/src/Shared/CodeAnalysis/DynamicallyAccessedMemberTypes.cs b/src/Shared/CodeAnalysis/DynamicallyAccessedMemberTypes.cs
index bfb1ec4c8e60..a8635d02db6c 100644
--- a/src/Shared/CodeAnalysis/DynamicallyAccessedMemberTypes.cs
+++ b/src/Shared/CodeAnalysis/DynamicallyAccessedMemberTypes.cs
@@ -1,7 +1,7 @@
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
-#if !NET5_0 && !NET6_0
+#if !NET5_0_OR_GREATER
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
diff --git a/src/Shared/CodeAnalysis/DynamicallyAccessedMembersAttribute.cs b/src/Shared/CodeAnalysis/DynamicallyAccessedMembersAttribute.cs
index 9b4124c2be1f..84d3f20d791d 100644
--- a/src/Shared/CodeAnalysis/DynamicallyAccessedMembersAttribute.cs
+++ b/src/Shared/CodeAnalysis/DynamicallyAccessedMembersAttribute.cs
@@ -1,7 +1,7 @@
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
-#if !NET5_0 && !NET6_0
+#if !NET5_0_OR_GREATER
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
diff --git a/src/Shared/CommandLineUtils/Utilities/DotNetMuxer.cs b/src/Shared/CommandLineUtils/Utilities/DotNetMuxer.cs
index 7f2a3a3a1fcb..3c33bc4768c7 100644
--- a/src/Shared/CommandLineUtils/Utilities/DotNetMuxer.cs
+++ b/src/Shared/CommandLineUtils/Utilities/DotNetMuxer.cs
@@ -4,7 +4,7 @@
// System.AppContext.GetData is not available in these frameworks
#nullable enable
-#if !NET451 && !NET452 && !NET46 && !NET461
+#if !NETFRAMEWORK
using System;
using System.Diagnostics;
diff --git a/src/Shared/ErrorPage/GeneratePage.ps1 b/src/Shared/ErrorPage/GeneratePage.ps1
index 2cba7d73289d..3f3028ae1252 100644
--- a/src/Shared/ErrorPage/GeneratePage.ps1
+++ b/src/Shared/ErrorPage/GeneratePage.ps1
@@ -1,5 +1,5 @@
$RepoRoot = Resolve-Path "$PSScriptRoot\..\..\.."
-$ToolPath = Join-Path "$RepoRoot" "artifacts\bin\RazorPageGenerator\Debug\net6.0\dotnet-razorpagegenerator.exe"
+$ToolPath = Join-Path "$RepoRoot" "artifacts\bin\RazorPageGenerator\Debug\net7.0\dotnet-razorpagegenerator.exe"
if (!(Test-Path "$ToolPath")) {
throw "Unable to find razor page generator tool at $ToolPath"
diff --git a/src/Shared/OperatingSystem.cs b/src/Shared/OperatingSystem.cs
index e2fb051d8907..c2f998d689ce 100644
--- a/src/Shared/OperatingSystem.cs
+++ b/src/Shared/OperatingSystem.cs
@@ -11,7 +11,7 @@ namespace Microsoft.AspNetCore
{
internal sealed class OperatingSystem
{
-#if NET461
+#if NETFRAMEWORK
private const bool _isBrowser = false;
#else
private static readonly bool _isBrowser = RuntimeInformation.IsOSPlatform(OSPlatform.Create("browser"));
diff --git a/src/Shared/test/Shared.Tests/PropertyHelperTest.cs b/src/Shared/test/Shared.Tests/PropertyHelperTest.cs
index 59ca00da4518..74517eddc163 100644
--- a/src/Shared/test/Shared.Tests/PropertyHelperTest.cs
+++ b/src/Shared/test/Shared.Tests/PropertyHelperTest.cs
@@ -164,7 +164,7 @@ public void PropertyHelper_RefStructProperties()
var helper = Assert.Single(PropertyHelper.GetProperties(obj.GetType().GetTypeInfo()));
Assert.Equal("Prop5", helper.Name);
}
-#elif NET46 || NET461
+#elif NETFRAMEWORK
#else
#error Unknown TFM - update the set of TFMs where we test for ref structs
#endif
@@ -746,7 +746,7 @@ private class RefStructProperties
private readonly ref struct MyRefStruct
{
}
-#elif NET46 || NET461
+#elif NETFRAMEWORK
#else
#error Unknown TFM - update the set of TFMs where we test for ref structs
#endif
diff --git a/src/SignalR/clients/csharp/Http.Connections.Client/src/Internal/WebSocketsTransport.cs b/src/SignalR/clients/csharp/Http.Connections.Client/src/Internal/WebSocketsTransport.cs
index 903a100160d7..8bb382142e8d 100644
--- a/src/SignalR/clients/csharp/Http.Connections.Client/src/Internal/WebSocketsTransport.cs
+++ b/src/SignalR/clients/csharp/Http.Connections.Client/src/Internal/WebSocketsTransport.cs
@@ -55,7 +55,7 @@ private async ValueTask DefaultWebSocketFactory(WebSocketConnectionCo
{
// Full Framework will throw when trying to set the User-Agent header
// So avoid setting it in netstandard2.0 and only set it in netstandard2.1 and higher
-#if !NETSTANDARD2_0 && !NET461
+#if !NETSTANDARD2_0 && !NETFRAMEWORK
webSocket.Options.SetRequestHeader("User-Agent", Constants.UserAgentHeader.ToString());
#else
// Set an alternative user agent header on Full framework
@@ -276,7 +276,7 @@ private async Task StartReceiving(WebSocket socket)
#if NETSTANDARD2_1 || NETCOREAPP
// Because we checked the CloseStatus from the 0 byte read above, we don't need to check again after reading
var receiveResult = await socket.ReceiveAsync(memory, CancellationToken.None);
-#elif NETSTANDARD2_0 || NET461
+#elif NETSTANDARD2_0 || NETFRAMEWORK
var isArray = MemoryMarshal.TryGetArray(memory, out var arraySegment);
Debug.Assert(isArray);
diff --git a/src/SignalR/clients/ts/FunctionalTests/scripts/run-tests.ts b/src/SignalR/clients/ts/FunctionalTests/scripts/run-tests.ts
index a7f51114689a..ea375516280d 100644
--- a/src/SignalR/clients/ts/FunctionalTests/scripts/run-tests.ts
+++ b/src/SignalR/clients/ts/FunctionalTests/scripts/run-tests.ts
@@ -245,7 +245,7 @@ function runJest(httpsUrl: string, httpUrl: string) {
(async () => {
try {
- const serverPath = path.resolve(ARTIFACTS_DIR, "bin", "SignalR.Client.FunctionalTestApp", configuration, "net6.0", "SignalR.Client.FunctionalTestApp.dll");
+ const serverPath = path.resolve(ARTIFACTS_DIR, "bin", "SignalR.Client.FunctionalTestApp", configuration, "net7.0", "SignalR.Client.FunctionalTestApp.dll");
debug(`Launching Functional Test Server: ${serverPath}`);
let desiredServerUrl = "https://127.0.0.1:0;http://127.0.0.1:0";
diff --git a/src/SignalR/publish-apps.ps1 b/src/SignalR/publish-apps.ps1
index d1bd4eb31051..170733f118e4 100644
--- a/src/SignalR/publish-apps.ps1
+++ b/src/SignalR/publish-apps.ps1
@@ -1,4 +1,4 @@
-param($RootDirectory = (Get-Location), $Framework = "net6.0", $Runtime = "win-x64", $CommitHash, $BranchName, $BuildNumber)
+param($RootDirectory = (Get-Location), $Framework = "net7.0", $Runtime = "win-x64", $CommitHash, $BranchName, $BuildNumber)
# De-Powershell the path
$RootDirectory = (Convert-Path $RootDirectory)
diff --git a/src/SiteExtensions/LoggingAggregate/src/Microsoft.AspNetCore.AzureAppServices.SiteExtension/Microsoft.AspNetCore.AzureAppServices.SiteExtension.csproj b/src/SiteExtensions/LoggingAggregate/src/Microsoft.AspNetCore.AzureAppServices.SiteExtension/Microsoft.AspNetCore.AzureAppServices.SiteExtension.csproj
index 8431a232cc89..d503a340f68c 100644
--- a/src/SiteExtensions/LoggingAggregate/src/Microsoft.AspNetCore.AzureAppServices.SiteExtension/Microsoft.AspNetCore.AzureAppServices.SiteExtension.csproj
+++ b/src/SiteExtensions/LoggingAggregate/src/Microsoft.AspNetCore.AzureAppServices.SiteExtension/Microsoft.AspNetCore.AzureAppServices.SiteExtension.csproj
@@ -34,6 +34,8 @@
+
+
diff --git a/src/Hosting/Server.IntegrationTesting/src/TestMatrix.cs b/src/Hosting/Server.IntegrationTesting/src/TestMatrix.cs
index 71c06aaadd4f..1676bb1b45d9 100644
--- a/src/Hosting/Server.IntegrationTesting/src/TestMatrix.cs
+++ b/src/Hosting/Server.IntegrationTesting/src/TestMatrix.cs
@@ -177,7 +177,7 @@ private void VaryByTfm(List variants, ServerType server, string ski
{
if (!CheckTfmIsSupportedForServer(tfm, server))
{
// Don't generate net461 variations for nginx server.
continue;
}
@@ -190,12 +190,12 @@ private void VaryByTfm(List variants, ServerType server, string ski
private bool CheckTfmIsSupportedForServer(string tfm, ServerType server)
{
// Not a combination we test
- return !(Tfm.Matches(Tfm.Net461, tfm) && ServerType.Nginx == server);
+ return !(Tfm.Matches(Tfm.Net462, tfm) && ServerType.Nginx == server);
}
private static string SkipIfTfmIsNotSupportedOnThisOS(string tfm)
{
- if (Tfm.Matches(Tfm.Net461, tfm) && !OperatingSystem.IsWindows())
+ if (Tfm.Matches(Tfm.Net462, tfm) && !OperatingSystem.IsWindows())
{
return "This TFM is not supported on this operating system.";
}
@@ -208,7 +208,7 @@ private void VaryByApplicationType(List variants, ServerType server
foreach (var t in ApplicationTypes)
{
var type = t;
- if (Tfm.Matches(Tfm.Net461, tfm) && type == ApplicationType.Portable)
+ if (Tfm.Matches(Tfm.Net462, tfm) && type == ApplicationType.Portable)
{
if (ApplicationTypes.Count == 1)
{
@@ -280,7 +280,7 @@ private void VaryByAncmHostingModel(IList variants, ServerType serv
if (hostingModel == HostingModel.InProcess)
{
// Not supported
- if (Tfm.Matches(Tfm.Net461, tfm) || Tfm.Matches(Tfm.NetCoreApp20, tfm))
+ if (Tfm.Matches(Tfm.Net462, tfm) || Tfm.Matches(Tfm.NetCoreApp20, tfm))
{
continue;
}
@@ -177,7 +177,7 @@ private void VaryByTfm(List variants, ServerType server, string ski
if (!CheckTfmIsSupportedForServer(tfm, server))
{
- // Don't generate net461 variations for nginx server.
+ // Don't generate net462 variations for nginx server.
continue;
}